@@ -53,7 +53,7 @@ const kXHTML_TRANSITIONAL = "resource://app/res/xhtml_transitional.xhtml";
 const kXHTML_STRICT = "resource://app/res/xhtml_strict.xhtml";
 const kHTML5 = "resource://app/res/html5.html";
 const kXHTML5 = "resource://app/res/xhtml5.xhtml";
-//@line 51 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 51 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 // implements nsIObserver
 var gEditorDocumentObserver =
@@ -273,7 +273,7 @@ var BlueGriffonPrefsObserver = {
   }
 };
 
-//@line 53 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 53 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 Components.utils.import("resource://app/modules/urlHelper.jsm");
 Components.utils.import("resource://app/modules/editorHelper.jsm");
@@ -331,9 +331,41 @@ function Startup()
   if (url)
     setTimeout(OpenFile, 100, url, true);
 
+  setTimeout(LoadLastTabs, 1000);
   BlueGriffonQuitHelper.init();
 }
-//@line 55 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+
+var gLastTabsArray;
+function LoadLastTabs()
+{
+  var lastTabs = "";
+  gLastTabsArray = [];
+  try {
+    lastTabs = GetPrefs().getCharPref("bluegriffon.defaults.lastTabs");
+    GetPrefs().setCharPref("bluegriffon.defaults.lastTabs", "");
+  }
+  catch(e) {}
+  if (lastTabs) {
+    gLastTabsArray = lastTabs.split("|");
+    //gLastTabsArray.reverse();
+    NotifierUtils.addNotifierCallback("tabCreated", OpenTabFromPreviousSession);
+    var url = gLastTabsArray.pop();
+    OpenFile(url, true);
+  }
+}
+
+function OpenTabFromPreviousSession(aReason, aContext)
+{
+  if (gLastTabsArray.length) {
+    var url = gLastTabsArray.pop();
+    OpenFile(url, true);
+  }
+  else {
+    NotifierUtils.removeNotifierCallback("tabCreated", OpenTabFromPreviousSession);
+  }
+}
+
+//@line 55 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 function Shutdown()
 {
@@ -365,12 +397,13 @@ function Shutdown()
 
 function onClose()
 {
+  SaveTabs();
   if (doSaveTabsBeforeQuit()) {
     Shutdown();
     return true;
   }
   return false;
-}//@line 57 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+}//@line 57 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 function OpenLocation(aEvent, type)
@@ -886,9 +919,9 @@ function ExplodeElement(aEvent)
       var parent = target.parentNode;
       editor.beginTransaction();
 
-      var child = target.lastChild;
+      var child = target.firstChild;
       while (child) {
-        var tmp = child.previousSibling;
+        var tmp = child.nextSibling;
         var clone = child.cloneNode(true)
         var txn = new diNodeInsertionTxn(clone, parent, target);
         editor.transactionManager.doTransaction(txn);
@@ -1075,11 +1108,13 @@ function ToggleViewMode(aElement)
       bespinEditor.blur();
       var oldSource = bespinIframe.getUserData("oldSource"); 
       if (source != oldSource) {
-        var doctype = EditorUtils.getCurrentDocument().doctype.publicId;
+        var doctype = EditorUtils.getCurrentDocument().doctype;
+        var publicId = doctype ? doctype.publicId : null;
         var isXML = false;
-        switch (doctype) {
+        switch (publicId) {
           case "http://www.w3.org/TR/html4/strict.dtd": // HTML 4
           case "http://www.w3.org/TR/html4/loose.dtd":
+          case null:
             isXML = false;
             break;
           case "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd": // XHTML 1
@@ -1182,13 +1217,6 @@ function RebuildFromSource(aDoc, aContext)
     CloneElementContents(editor, aDoc.querySelector("head"), editor.document.querySelector("head"));
     // clone body
     CloneElementContents(editor, aDoc.querySelector("body"), editor.document.body);
-    /*var child = editor.document.body.lastChild;
-    if (!child || child.nodeName.toLowerCase() != "br") { // CreateTrailingBRIfNeeded
-      var mozbr = editor.document.createElement("br");
-      mozbr.setAttribute("type", "_moz");
-      editor.insertNode(mozbr, editor.document.body, editor.document.body.childNodes.length);
-    }
-    editor.endOfDocument();*/
     editor.endTransaction();
 
     // the window title is updated by DOMTitleChanged event
@@ -1222,9 +1250,7 @@ function doCloseTab(aTab)
   }
   window.updateCommands("style");
   NotifierUtils.notify("tabClosed");
-  if (gDialog.tabeditor)
-    gDialog.tabeditor.updateOSXCloseButton();
-  UpdateBadge();
+//@line 908 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 }
 
 function SetLocationDB()
@@ -1266,10 +1292,6 @@ function doSaveTabsBeforeQuit()
 
 function doQuit()
 {
-/*  alert(gDialog.MainToolbox)
-  if (EditorUtils.getCurrentEditorElement() &&
-      gDialog.wysiwygModeButton)
-    ToggleViewMode(gDialog.wysiwygModeButton);*/
   return doSaveTabsBeforeQuit();
 }
 
@@ -1753,6 +1775,24 @@ function BespinReplaceAll()
 function WysiwygShowFindBar()
 {
   gDialog.bespinToolbox1.hidden = false;
+  var editor = EditorUtils.getCurrentEditor();
+  if (GetCurrentViewMode() == "wysiwyg") {
+    var text = editor.outputToString("text/plain", 1).trim();
+    if (text) {
+      gDialog.bespinFindTextbox.value = text;
+      BespinFind(true, true);
+    }
+  }
+  else {
+    var bespinIframe = EditorUtils.getCurrentSourceEditorElement();
+    var bespinEditor = bespinIframe.contentWindow.gEditor;
+    var selectionRange = bespinEditor.getSelectionRange();
+    var text = bespinEditor.getSession().getTextRange(selectionRange)
+    if (text) {
+      gDialog.bespinFindTextbox.value = text;
+      BespinFind(true, true);
+    }
+  }
   gDialog.bespinFindTextbox.focus();
 }
 
@@ -1833,7 +1873,7 @@ function ReplaceInWysiwyg()
   return true;
 }
 
-//@line 1207 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1200 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 var AutoInsertTable = {
@@ -1968,7 +2008,7 @@ var AutoInsertTable = {
     }
   }
 };
-//@line 1209 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1202 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 function AlignAllPanels()
@@ -1979,9 +2019,9 @@ function AlignAllPanels()
 
 function UpdatePanelsStatusInMenu()
 {
-//@line 1221 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1214 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   return;
-//@line 1224 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1217 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   var child = gDialog.beforeAllPanelsMenuseparator.nextSibling;
   while (child) {
     var panel = gDialog[child.getAttribute("panel")];
@@ -1996,10 +2036,10 @@ function UpdatePanelsStatusInMenu()
 
 function TogglePanel(aEvent)
 {
-//@line 1240 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1233 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   start_css();
   return;
-//@line 1244 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1237 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   var menuitem = aEvent.originalTarget;
   if (!menuitem.hasAttribute("panel"))
     return;
@@ -2043,11 +2083,13 @@ function start_css()
 
 function UpdateTabHTMLDialect(editor)
 {
-  var doctype = editor.document.doctype.systemId;
+  var doctype = editor.document.doctype;
+  var systemId = doctype ? doctype.systemId : null;
   var tab = gDialog.tabeditor.selectedTab;
-  switch (doctype) {
+  switch (systemId) {
     case "http://www.w3.org/TR/html4/strict.dtd": // HTML 4
     case "http://www.w3.org/TR/html4/loose.dtd":
+    case null:
       tab.setAttribute("tooltiptext", "HTML 4");
       break;
     case "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd": // XHTML 1
@@ -2199,7 +2241,7 @@ function IgnoreWord()
   sc.ignoreWord();
 }
 
-//@line 1444 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1439 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 function OpenCharInsertionDialog()
 {
   var w = null;
@@ -2213,7 +2255,7 @@ function OpenCharInsertionDialog()
    window.openDialog("chrome://bluegriffon/content/dialogs/insertChars.xul","_blank",
                      "chrome,modal=no,titlebar");
 }
-//@line 1458 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1453 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 var gDummySelectionStartNode = null;
@@ -2246,18 +2288,25 @@ function MarkSelection()
       startContainer.data = data;
     }
     else if (startContainer.nodeType == Node.ELEMENT_NODE) {
-      var node = startContainer.childNodes.item(startOffset);
-      if (node.nodeType == Node.TEXT_NODE) {
-        var data = node.data;
-        gDummySelectionStartNode = node;
-        gDummySelectionStartData = data;
-        data = kBGBGBG + data;
-        node.data = data;
+      if (startOffset < startContainer.childNodes.length) {
+        var node = startContainer.childNodes.item(startOffset);
+        if (node.nodeType == Node.TEXT_NODE) {
+          var data = node.data;
+          gDummySelectionStartNode = node;
+          gDummySelectionStartData = data;
+          data = kBGBGBG + data;
+          node.data = data;
+        }
+        else {
+          var t = EditorUtils.getCurrentDocument().createTextNode(kBGBGBG);
+          gDummySelectionStartNode = t;
+          startContainer.insertBefore(t, node);
+        }
       }
       else {
         var t = EditorUtils.getCurrentDocument().createTextNode(kBGBGBG);
         gDummySelectionStartNode = t;
-        startContainer.insertBefore(t, node);
+        startContainer.appendChild(t);
       }
     }
 
@@ -2373,3 +2422,33 @@ function UseAceTheme(aEvent)
   aceIframe.contentWindow.useTheme(theme);
 }
 
+//@line 1649 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+
+function SaveCurrentTabLocation()
+{
+  try {
+    if (!GetPrefs().getBoolPref("bluegriffon.defaults.restorePreviousSession"))
+      return;
+  }
+  catch(e) {}
+
+  var URL = EditorUtils.getDocumentUrl();
+  var lastTabs = "";
+  try {
+    lastTabs = GetPrefs().getCharPref("bluegriffon.defaults.lastTabs");
+  }
+  catch(e) {}
+  lastTabs += (lastTabs ? "|" : "") + URL;
+  try {
+    GetPrefs().setCharPref("bluegriffon.defaults.lastTabs", lastTabs);
+  }
+  catch(e) {}
+}
+
+function SaveTabs()
+{
+  try {
+    GetPrefs().setCharPref("bluegriffon.defaults.lastTabs", "");
+  }
+  catch(e) {}
+}
