@@ -396,6 +396,8 @@ var ComposerCommands = {
 
     commandTable.registerCommand("cmd_copyHTMLCode", cmdCopyHTMLCodeCommand);
     commandTable.registerCommand("cmd_gotoLink",    cmdGotoLinkCommand);
+
+    commandTable.registerCommand("cmd_structureClimb", cmdStructureClimbCommand);
 },
 
   setupFormatCommands: function setupFormatCommands()
@@ -589,10 +591,10 @@ var cmdSave =
     try {
       var docUrl = EditorUtils.getDocumentUrl();
       return EditorUtils.isDocumentEditable()
-        && GetCurrentViewMode() == "wysiwyg"
-        && (EditorUtils.isDocumentModified()
-            || UrlUtils.isUrlOfBlankDocument(docUrl)
-            || UrlUtils.getScheme(docUrl) != "file");
+			        && (GetCurrentViewMode() == "source"
+					        || (EditorUtils.isDocumentModified()
+					            || UrlUtils.isUrlOfBlankDocument(docUrl)
+					            || UrlUtils.getScheme(docUrl) != "file"));
     } catch (e) {return false;}
   },
   
@@ -605,14 +607,24 @@ var cmdSave =
     var editor = EditorUtils.getCurrentEditor();
     if (editor)
       try {
-        if (gDialog.wysiwygModeButton)
-          ToggleViewMode(gDialog.wysiwygModeButton);
-        // for the time being, we use the HTML serializer
-  
-        result = FileUtils.saveDocument(
-                   UrlUtils.isUrlOfBlankDocument(EditorUtils.getDocumentUrl()),
-                   false,
-                   EditorUtils.getCurrentDocumentMimeType());
+        var mode = GetCurrentViewMode();
+        if (mode == "source") {
+          var editorElement = EditorUtils.getCurrentEditorElement();
+			    var bespinIframe = editorElement.previousSibling;
+			    var bespinEditor = bespinIframe.contentWindow.gEditor;
+          var source = bespinEditor.getSession().getValue();
+
+          result = FileUtils.saveSourceDocument(source,
+                     UrlUtils.isUrlOfBlankDocument(EditorUtils.getDocumentUrl()),
+                     false,
+                     EditorUtils.getCurrentDocumentMimeType());
+        }
+        else {
+	        result = FileUtils.saveDocument(
+	                   UrlUtils.isUrlOfBlankDocument(EditorUtils.getDocumentUrl()),
+	                   false,
+	                   EditorUtils.getCurrentDocumentMimeType());
+        }
         window.content.focus();
         if (result)
           StoreUrlInLocationDB(EditorUtils.getDocumentUrl());
@@ -626,7 +638,7 @@ var cmdSaveAs =
 {
   isCommandEnabled: function(aCommand, dummy)
   {
-    return (EditorUtils.isDocumentEditable() && GetCurrentViewMode() == "wysiwyg");
+    return EditorUtils.isDocumentEditable();
   },
 
   getCommandStateParams: function(aCommand, aParams, aRefCon) {},
@@ -634,20 +646,34 @@ var cmdSaveAs =
 
   doCommand: function(aCommand)
   {
+    var result = false;
     var editor = EditorUtils.getCurrentEditor();
     if (editor)
-    try {
-      if (gDialog.wysiwygModeButton)
-        ToggleViewMode(gDialog.wysiwygModeButton);
-      var editorMimeType = EditorUtils.getCurrentDocument().contentType;
-      var result = FileUtils.saveDocument(true, false, editorMimeType);
-      if (result)
-        StoreUrlInLocationDB(EditorUtils.getDocumentUrl());
-      window.content.focus();
-      return result;
-    }
-    catch (e) {}
-    return false;
+      try {
+        var mode = GetCurrentViewMode();
+        if (mode == "source") {
+          var editorElement = EditorUtils.getCurrentEditorElement();
+          var bespinIframe = editorElement.previousSibling;
+          var bespinEditor = bespinIframe.contentWindow.gEditor;
+          var source = bespinEditor.getSession().getValue();
+
+          result = FileUtils.saveSourceDocument(source,
+                     true,
+                     false,
+                     EditorUtils.getCurrentDocumentMimeType());
+        }
+        else {
+          result = FileUtils.saveDocument(
+                     true,
+                     false,
+                     EditorUtils.getCurrentDocumentMimeType());
+        }
+        window.content.focus();
+        if (result)
+          StoreUrlInLocationDB(EditorUtils.getDocumentUrl());
+      }
+      catch (e) {}
+    return result;
   }
 }
 
@@ -923,6 +949,38 @@ var cmdGotoLinkCommand =
     }
   }
 };
+
+var cmdStructureClimbCommand =
+{
+  isCommandEnabled: function(aCommand, dummy)
+  {
+    return (EditorUtils.getCurrentEditorElement() &&
+            EditorUtils.isDocumentEditable() &&
+            EditorUtils.isEditingRenderedHTML() &&
+            !EditorUtils.activeViewActive  &&
+            GetCurrentViewMode() == "wysiwyg");
+  },
+
+  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
+  doCommandParams: function(aCommand, aParams, aRefCon) {},
+
+  doCommand: function(aCommand)
+  {
+    var mixed = EditorUtils.getSelectionContainer();
+    if (!mixed) return;
+    var element = mixed.node;
+    var oneElementSelected = mixed.oneElementSelected;
+    var editor = EditorUtils.getCurrentEditor();
+    if (oneElementSelected) {
+      if (element.parentNode && element.parentNode != element.ownerDocument.documentElement)
+        editor.selectElement(element.parentNode)
+    }
+    else
+      editor.selectElement(element);
+  }
+
+};
+
 //-----------------------------------------------------------------------------------
 
 var cmdClass =
@@ -2494,5 +2552,5 @@ var bgSelectTableColumnCommand =
 };
 
 
-//@line 504 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/commands.js"
+//@line 506 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/commands.js"
 
