@@ -21,7 +21,8 @@ pref("javascript.options.strict", false);
 pref("nglayout.debug.disable_xul_cache", true);
 pref("nglayout.debug.disable_xul_fastload", true);
 
-pref("general.useragent.extra.mybrowser", "bluegriffon/1.0");
+pref("general.useragent.extra.mybrowser", "bluegriffon/1.1.1");
+pref("intl.locale.matchOS", true);
 
 pref("extensions.update.enabled", false);
 pref("extensions.update.url", "chrome://mozapps/locale/extensions/extensions.properties");
@@ -33,6 +34,8 @@ pref("extensions.getMoreThemesURL", "chrome://mozapps/locale/extensions/extensio
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching                                               
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
                                                 // restart.
+pref("extensions.closeOnEscape", true);
+
 // browser preferences
 pref("bluegriffon.display.use_system_colors", true);
 pref("bluegriffon.display.foreground_color", "#000000");
@@ -115,3 +118,4 @@ pref("bluegriffon.source.entities", "basic");
 pref("bluegriffon.tabs.position", "center");
 
 pref("bluegriffon.osx.dock-integration", true);
+pref("extensions.getAddons.cache.enabled", false);
