@@ -47,8 +47,13 @@ function urlSecurityCheck(aURL, aPrincipal, aFlags)
     else
       secMan.checkLoadURIStrWithPrincipal(aPrincipal, aURL, aFlags);
   } catch (e) {
-    // XXXmano: dump the principal url here too
-    throw "Load of " + aURL + " denied.";
+    let principalStr = "";
+    try {
+      principalStr = " from " + aPrincipal.URI.spec;
+    }
+    catch(e2) { }
+
+    throw "Load of " + aURL + principalStr + " denied.";
   }
 }
 
@@ -931,7 +936,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 979 "/home/glazou/trees/OFFICIAL_1.0/toolkit/content/contentAreaUtils.js"
+//@line 984 "/home/glazou/trees/OFFICIAL_1.0/toolkit/content/contentAreaUtils.js"
 
   // Remove leading dots
   aFile = aFile.replace(/^\.+/, "");
