@@ -251,7 +251,7 @@ function openDownload(aDownload)
       dontAsk = !pref.getBoolPref(PREF_BDM_ALERTONEXEOPEN);
     } catch (e) { }
 
-//@line 311 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/content/downloads.js"
+//@line 309 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/content/downloads.js"
 
     if (!dontAsk) {
       var strings = document.getElementById("downloadStrings");
@@ -435,7 +435,7 @@ function Startup()
     }
   }, false);
 
-//@line 501 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/content/downloads.js"
+//@line 497 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/content/downloads.js"
 }
 
 function Shutdown()
@@ -491,11 +491,11 @@ let gDownloadObserver = {
         }
         break;
       case "browser-lastwindow-close-granted":
-//@line 557 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/content/downloads.js"
+//@line 553 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/content/downloads.js"
         if (gDownloadManager.activeDownloadCount == 0) {
           setTimeout(gCloseDownloadManager, 0);
         }
-//@line 561 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/content/downloads.js"
+//@line 557 "/home/glazou/trees/OFFICIAL_1.0/toolkit/mozapps/downloads/content/downloads.js"
         break;
     }
   }
@@ -1129,11 +1129,11 @@ function buildDownloadList(aForceBuild)
   }
 
   try {
-    gStmt.bindInt32Parameter(0, nsIDM.DOWNLOAD_NOTSTARTED);
-    gStmt.bindInt32Parameter(1, nsIDM.DOWNLOAD_DOWNLOADING);
-    gStmt.bindInt32Parameter(2, nsIDM.DOWNLOAD_PAUSED);
-    gStmt.bindInt32Parameter(3, nsIDM.DOWNLOAD_QUEUED);
-    gStmt.bindInt32Parameter(4, nsIDM.DOWNLOAD_SCANNING);
+    gStmt.bindByIndex(0, nsIDM.DOWNLOAD_NOTSTARTED);
+    gStmt.bindByIndex(1, nsIDM.DOWNLOAD_DOWNLOADING);
+    gStmt.bindByIndex(2, nsIDM.DOWNLOAD_PAUSED);
+    gStmt.bindByIndex(3, nsIDM.DOWNLOAD_QUEUED);
+    gStmt.bindByIndex(4, nsIDM.DOWNLOAD_SCANNING);
   } catch (e) {
     // Something must have gone wrong when binding, so clear and quit
     gStmt.reset();
